package com.ruoyi.os.mapper;


import com.ruoyi.os.domain.HealthcareOsConventionalPrescriptions;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

/**
 * 常规处方Mapper接口
 *
 * @author 何顺
 * @date 2024-10-19
 */
@Mapper
public interface HealthcareOsConventionalPrescriptionsMapper
{
    /**
     * 查询常规处方
     *
     * @param id 常规处方主键
     * @return 常规处方
     */
    public HealthcareOsConventionalPrescriptions selectHealthcareOsConventionalPrescriptionsById(Long id);

    /**
     * 查询常规处方列表
     *
     * @param healthcareOsConventionalPrescriptions 常规处方
     * @return 常规处方集合
     */
    public List<HealthcareOsConventionalPrescriptions> selectHealthcareOsConventionalPrescriptionsList(HealthcareOsConventionalPrescriptions healthcareOsConventionalPrescriptions);

    /**
     * 新增常规处方
     *
     * @param healthcareOsConventionalPrescriptions 常规处方
     * @return 结果
     */
    public int insertHealthcareOsConventionalPrescriptions(HealthcareOsConventionalPrescriptions healthcareOsConventionalPrescriptions);

    /**
     * 修改常规处方
     *
     * @param healthcareOsConventionalPrescriptions 常规处方
     * @return 结果
     */
    public int updateHealthcareOsConventionalPrescriptions(HealthcareOsConventionalPrescriptions healthcareOsConventionalPrescriptions);

    /**
     * 删除常规处方
     *
     * @param id 常规处方主键
     * @return 结果
     */
    public int deleteHealthcareOsConventionalPrescriptionsById(Long id);

    /**
     * 批量删除常规处方
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteHealthcareOsConventionalPrescriptionsByIds(Long[] ids);
}
